Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type NetworkPolicyRecommendation
- type NetworkPolicyRecommendationList
- type NetworkPolicyRecommendationSpec
- type NetworkPolicyRecommendationStatus
- type ThroughputAnomalyDetector
- type ThroughputAnomalyDetectorList
- type ThroughputAnomalyDetectorSpec
- type ThroughputAnomalyDetectorStatus
Constants ¶
const ( NPRecommendationStateNew string = "NEW" NPRecommendationStateScheduled string = "SCHEDULED" NPRecommendationStateRunning string = "RUNNING" NPRecommendationStateCompleted string = "COMPLETED" NPRecommendationStateFailed string = "FAILED" ThroughputAnomalyDetectorStateNew string = "NEW" ThroughputAnomalyDetectorStateScheduled string = "SCHEDULED" ThroughputAnomalyDetectorStateRunning string = "RUNNING" ThroughputAnomalyDetectorStateCompleted string = "COMPLETED" ThroughputAnomalyDetectorStateFailed string = "FAILED" )
const GroupName = "crd.theia.antrea.io"
Variables ¶
var ( SchemeBuilder runtime.SchemeBuilder AddToScheme = localSchemeBuilder.AddToScheme )
var ( SchemeGroupVersion = schema.GroupVersion{ Group: GroupName, Version: "v1alpha1"} )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Types ¶
type NetworkPolicyRecommendation ¶
type NetworkPolicyRecommendation struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec NetworkPolicyRecommendationSpec `json:"spec,omitempty"`
Status NetworkPolicyRecommendationStatus `json:"status,omitempty"`
}
func (*NetworkPolicyRecommendation) DeepCopy ¶
func (in *NetworkPolicyRecommendation) DeepCopy() *NetworkPolicyRecommendation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyRecommendation.
func (*NetworkPolicyRecommendation) DeepCopyInto ¶
func (in *NetworkPolicyRecommendation) DeepCopyInto(out *NetworkPolicyRecommendation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NetworkPolicyRecommendation) DeepCopyObject ¶
func (in *NetworkPolicyRecommendation) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NetworkPolicyRecommendationList ¶
type NetworkPolicyRecommendationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []NetworkPolicyRecommendation `json:"items"`
}
func (*NetworkPolicyRecommendationList) DeepCopy ¶
func (in *NetworkPolicyRecommendationList) DeepCopy() *NetworkPolicyRecommendationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyRecommendationList.
func (*NetworkPolicyRecommendationList) DeepCopyInto ¶
func (in *NetworkPolicyRecommendationList) DeepCopyInto(out *NetworkPolicyRecommendationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NetworkPolicyRecommendationList) DeepCopyObject ¶
func (in *NetworkPolicyRecommendationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NetworkPolicyRecommendationSpec ¶
type NetworkPolicyRecommendationSpec struct {
JobType string `json:"jobType,omitempty"`
Limit int `json:"limit,omitempty"`
PolicyType string `json:"policyType,omitempty"`
StartInterval metav1.Time `json:"startInterval,omitempty"`
EndInterval metav1.Time `json:"endInterval,omitempty"`
NSAllowList []string `json:"nsAllowList,omitempty"`
ExcludeLabels bool `json:"excludeLabels,omitempty"`
ToServices bool `json:"toServices,omitempty"`
ExecutorInstances int `json:"executorInstances,omitempty"`
DriverCoreRequest string `json:"driverCoreRequest,omitempty"`
DriverMemory string `json:"driverMemory,omitempty"`
ExecutorCoreRequest string `json:"executorCoreRequest,omitempty"`
ExecutorMemory string `json:"executorMemory,omitempty"`
}
func (*NetworkPolicyRecommendationSpec) DeepCopy ¶
func (in *NetworkPolicyRecommendationSpec) DeepCopy() *NetworkPolicyRecommendationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyRecommendationSpec.
func (*NetworkPolicyRecommendationSpec) DeepCopyInto ¶
func (in *NetworkPolicyRecommendationSpec) DeepCopyInto(out *NetworkPolicyRecommendationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NetworkPolicyRecommendationStatus ¶
type NetworkPolicyRecommendationStatus struct {
State string `json:"state,omitempty"`
SparkApplication string `json:"sparkApplication,omitempty"`
CompletedStages int `json:"completedStages,omitempty"`
TotalStages int `json:"totalStages,omitempty"`
ErrorMsg string `json:"errorMsg,omitempty"`
StartTime metav1.Time `json:"startTime,omitempty"`
EndTime metav1.Time `json:"endTime,omitempty"`
}
func (*NetworkPolicyRecommendationStatus) DeepCopy ¶
func (in *NetworkPolicyRecommendationStatus) DeepCopy() *NetworkPolicyRecommendationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyRecommendationStatus.
func (*NetworkPolicyRecommendationStatus) DeepCopyInto ¶
func (in *NetworkPolicyRecommendationStatus) DeepCopyInto(out *NetworkPolicyRecommendationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ThroughputAnomalyDetector ¶ added in v0.5.0
type ThroughputAnomalyDetector struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ThroughputAnomalyDetectorSpec `json:"spec,omitempty"`
Status ThroughputAnomalyDetectorStatus `json:"status,omitempty"`
}
func (*ThroughputAnomalyDetector) DeepCopy ¶ added in v0.5.0
func (in *ThroughputAnomalyDetector) DeepCopy() *ThroughputAnomalyDetector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ThroughputAnomalyDetector.
func (*ThroughputAnomalyDetector) DeepCopyInto ¶ added in v0.5.0
func (in *ThroughputAnomalyDetector) DeepCopyInto(out *ThroughputAnomalyDetector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ThroughputAnomalyDetector) DeepCopyObject ¶ added in v0.5.0
func (in *ThroughputAnomalyDetector) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ThroughputAnomalyDetectorList ¶ added in v0.5.0
type ThroughputAnomalyDetectorList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ThroughputAnomalyDetector `json:"items"`
}
func (*ThroughputAnomalyDetectorList) DeepCopy ¶ added in v0.5.0
func (in *ThroughputAnomalyDetectorList) DeepCopy() *ThroughputAnomalyDetectorList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ThroughputAnomalyDetectorList.
func (*ThroughputAnomalyDetectorList) DeepCopyInto ¶ added in v0.5.0
func (in *ThroughputAnomalyDetectorList) DeepCopyInto(out *ThroughputAnomalyDetectorList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ThroughputAnomalyDetectorList) DeepCopyObject ¶ added in v0.5.0
func (in *ThroughputAnomalyDetectorList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ThroughputAnomalyDetectorSpec ¶ added in v0.5.0
type ThroughputAnomalyDetectorSpec struct {
JobType string `json:"jobType,omitempty"`
StartInterval metav1.Time `json:"startInterval,omitempty"`
EndInterval metav1.Time `json:"endInterval,omitempty"`
NSIgnoreList []string `json:"nsIgnoreList,omitempty"`
AggregatedFlow string `json:"aggFlow,omitempty"`
PodLabel string `json:"podLabel,omitempty"`
PodName string `json:"podName,omitempty"`
PodNameSpace string `json:"podNameSpace,omitempty"`
ExternalIP string `json:"externalIp,omitempty"`
ServicePortName string `json:"servicePortName,omitempty"`
ExecutorInstances int `json:"executorInstances,omitempty"`
DriverCoreRequest string `json:"driverCoreRequest,omitempty"`
DriverMemory string `json:"driverMemory,omitempty"`
ExecutorCoreRequest string `json:"executorCoreRequest,omitempty"`
ExecutorMemory string `json:"executorMemory,omitempty"`
}
func (*ThroughputAnomalyDetectorSpec) DeepCopy ¶ added in v0.5.0
func (in *ThroughputAnomalyDetectorSpec) DeepCopy() *ThroughputAnomalyDetectorSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ThroughputAnomalyDetectorSpec.
func (*ThroughputAnomalyDetectorSpec) DeepCopyInto ¶ added in v0.5.0
func (in *ThroughputAnomalyDetectorSpec) DeepCopyInto(out *ThroughputAnomalyDetectorSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ThroughputAnomalyDetectorStatus ¶ added in v0.5.0
type ThroughputAnomalyDetectorStatus struct {
State string `json:"state,omitempty"`
SparkApplication string `json:"sparkApplication,omitempty"`
CompletedStages int `json:"completedStages,omitempty"`
TotalStages int `json:"totalStages,omitempty"`
ErrorMsg string `json:"errorMsg,omitempty"`
StartTime metav1.Time `json:"startTime,omitempty"`
EndTime metav1.Time `json:"endTime,omitempty"`
}
func (*ThroughputAnomalyDetectorStatus) DeepCopy ¶ added in v0.5.0
func (in *ThroughputAnomalyDetectorStatus) DeepCopy() *ThroughputAnomalyDetectorStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ThroughputAnomalyDetectorStatus.
func (*ThroughputAnomalyDetectorStatus) DeepCopyInto ¶ added in v0.5.0
func (in *ThroughputAnomalyDetectorStatus) DeepCopyInto(out *ThroughputAnomalyDetectorStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.