Documentation
¶
Index ¶
Constants ¶
const GroupName = "stats.theia.antrea.io"
Variables ¶
var ( SchemeGroupVersion = schema.GroupVersion{ Group: GroupName, Version: "v1alpha1"} StatusResource = schema.GroupVersionResource{ Group: SchemeGroupVersion.Group, Version: SchemeGroupVersion.Version, Resource: "clickhouse"} )
var ( SchemeBuilder runtime.SchemeBuilder AddToScheme = localSchemeBuilder.AddToScheme )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Types ¶
type ClickHouseStats ¶
type ClickHouseStats struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
DiskInfos []DiskInfo `json:"diskInfos,omitempty"`
TableInfos []TableInfo `json:"tableInfos,omitempty"`
InsertRates []InsertRate `json:"insertRates,omitempty"`
StackTraces []StackTrace `json:"stackTraces,omitempty"`
ErrorMsg []string `json:"errorMsg,omitempty"`
}
func (*ClickHouseStats) DeepCopy ¶
func (in *ClickHouseStats) DeepCopy() *ClickHouseStats
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClickHouseStats.
func (*ClickHouseStats) DeepCopyInto ¶
func (in *ClickHouseStats) DeepCopyInto(out *ClickHouseStats)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClickHouseStats) DeepCopyObject ¶
func (in *ClickHouseStats) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DiskInfo ¶
type DiskInfo struct {
Shard string `json:"shard,omitempty"`
Database string `json:"name,omitempty"`
Path string `json:"path,omitempty"`
FreeSpace string `json:"freeSpace,omitempty"`
TotalSpace string `json:"totalSpace,omitempty"`
UsedPercentage string `json:"usedPercentage,omitempty"`
}
func (*DiskInfo) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskInfo.
func (*DiskInfo) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InsertRate ¶
type InsertRate struct {
Shard string `json:"shard,omitempty"`
RowsPerSec string `json:"rowsPerSec,omitempty"`
BytesPerSec string `json:"bytesPerSec,omitempty"`
}
func (*InsertRate) DeepCopy ¶
func (in *InsertRate) DeepCopy() *InsertRate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InsertRate.
func (*InsertRate) DeepCopyInto ¶
func (in *InsertRate) DeepCopyInto(out *InsertRate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type StackTrace ¶
type StackTrace struct {
Shard string `json:"shard,omitempty"`
TraceFunctions string `json:"traceFunctions,omitempty"`
Count string `json:"count,omitempty"`
}
func (*StackTrace) DeepCopy ¶
func (in *StackTrace) DeepCopy() *StackTrace
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StackTrace.
func (*StackTrace) DeepCopyInto ¶
func (in *StackTrace) DeepCopyInto(out *StackTrace)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TableInfo ¶
type TableInfo struct {
Shard string `json:"shard,omitempty"`
Database string `json:"database,omitempty"`
TableName string `json:"tableName,omitempty"`
TotalRows string `json:"totalRows,omitempty"`
TotalBytes string `json:"totalBytes,omitempty"`
TotalCols string `json:"totalCols,omitempty"`
}
func (*TableInfo) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TableInfo.
func (*TableInfo) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.