Documentation
¶
Index ¶
- type NetworkPolicyRecommendationLister
- type NetworkPolicyRecommendationListerExpansion
- type NetworkPolicyRecommendationNamespaceLister
- type NetworkPolicyRecommendationNamespaceListerExpansion
- type ThroughputAnomalyDetectorLister
- type ThroughputAnomalyDetectorListerExpansion
- type ThroughputAnomalyDetectorNamespaceLister
- type ThroughputAnomalyDetectorNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NetworkPolicyRecommendationLister ¶
type NetworkPolicyRecommendationLister interface {
// List lists all NetworkPolicyRecommendations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.NetworkPolicyRecommendation, err error)
// NetworkPolicyRecommendations returns an object that can list and get NetworkPolicyRecommendations.
NetworkPolicyRecommendations(namespace string) NetworkPolicyRecommendationNamespaceLister
NetworkPolicyRecommendationListerExpansion
}
NetworkPolicyRecommendationLister helps list NetworkPolicyRecommendations. All objects returned here must be treated as read-only.
func NewNetworkPolicyRecommendationLister ¶
func NewNetworkPolicyRecommendationLister(indexer cache.Indexer) NetworkPolicyRecommendationLister
NewNetworkPolicyRecommendationLister returns a new NetworkPolicyRecommendationLister.
type NetworkPolicyRecommendationListerExpansion ¶
type NetworkPolicyRecommendationListerExpansion interface{}
NetworkPolicyRecommendationListerExpansion allows custom methods to be added to NetworkPolicyRecommendationLister.
type NetworkPolicyRecommendationNamespaceLister ¶
type NetworkPolicyRecommendationNamespaceLister interface {
// List lists all NetworkPolicyRecommendations in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.NetworkPolicyRecommendation, err error)
// Get retrieves the NetworkPolicyRecommendation from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.NetworkPolicyRecommendation, error)
NetworkPolicyRecommendationNamespaceListerExpansion
}
NetworkPolicyRecommendationNamespaceLister helps list and get NetworkPolicyRecommendations. All objects returned here must be treated as read-only.
type NetworkPolicyRecommendationNamespaceListerExpansion ¶
type NetworkPolicyRecommendationNamespaceListerExpansion interface{}
NetworkPolicyRecommendationNamespaceListerExpansion allows custom methods to be added to NetworkPolicyRecommendationNamespaceLister.
type ThroughputAnomalyDetectorLister ¶ added in v0.5.0
type ThroughputAnomalyDetectorLister interface {
// List lists all ThroughputAnomalyDetectors in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ThroughputAnomalyDetector, err error)
// ThroughputAnomalyDetectors returns an object that can list and get ThroughputAnomalyDetectors.
ThroughputAnomalyDetectors(namespace string) ThroughputAnomalyDetectorNamespaceLister
ThroughputAnomalyDetectorListerExpansion
}
ThroughputAnomalyDetectorLister helps list ThroughputAnomalyDetectors. All objects returned here must be treated as read-only.
func NewThroughputAnomalyDetectorLister ¶ added in v0.5.0
func NewThroughputAnomalyDetectorLister(indexer cache.Indexer) ThroughputAnomalyDetectorLister
NewThroughputAnomalyDetectorLister returns a new ThroughputAnomalyDetectorLister.
type ThroughputAnomalyDetectorListerExpansion ¶ added in v0.5.0
type ThroughputAnomalyDetectorListerExpansion interface{}
ThroughputAnomalyDetectorListerExpansion allows custom methods to be added to ThroughputAnomalyDetectorLister.
type ThroughputAnomalyDetectorNamespaceLister ¶ added in v0.5.0
type ThroughputAnomalyDetectorNamespaceLister interface {
// List lists all ThroughputAnomalyDetectors in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ThroughputAnomalyDetector, err error)
// Get retrieves the ThroughputAnomalyDetector from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ThroughputAnomalyDetector, error)
ThroughputAnomalyDetectorNamespaceListerExpansion
}
ThroughputAnomalyDetectorNamespaceLister helps list and get ThroughputAnomalyDetectors. All objects returned here must be treated as read-only.
type ThroughputAnomalyDetectorNamespaceListerExpansion ¶ added in v0.5.0
type ThroughputAnomalyDetectorNamespaceListerExpansion interface{}
ThroughputAnomalyDetectorNamespaceListerExpansion allows custom methods to be added to ThroughputAnomalyDetectorNamespaceLister.