Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ManagerDumper ¶
type ManagerDumper interface {
// DumpLog should create files that contains container logs of the manager
// Pod under the basedir.
DumpLog(basedir string) error
DumpClickHouseServerLog(basedir string) error
DumpFlowAggregatorLog(basedir string) error
DumpGrafanaLog(basedir string) error
DumpSparkDriverLog(basedir string) error
DumpSparkExecutorLog(basedir string) error
DumpSparkOperatorLog(basedir string) error
DumpZookeeperLog(basedir string) error
}
ManagerDumper is the interface for dumping runtime information of the flow visibility solution. Its functions should only work in the theia manager Pod.
func NewManagerDumper ¶
func NewManagerDumper(fs afero.Fs, restConfig *rest.Config, clientSet kubernetes.Interface, since string, namespace string, clickhousePodNames, grafanaPodNames, flowAggregatorPodNames, sparkDriverPodNames, sparkExecutorPodNames, sparkOperatorPodNames, zookeeperPodNames []string) ManagerDumper
Click to show internal directories.
Click to hide internal directories.